@@ -138,7 +138,7 @@ CalcEngine::ResultCode CalcEngine::calculate(const QQueue<KCalcToken> tokenBuffe
         case KCalcToken::TokenType::RIGHT_UNARY_FUNCTION_TYPE:
             if (token_index + 1 >= buffer_size) {
                 errorIndex = token_index;
-                return MISIING_RIGHT_UNARY_ARG;
+                return MISSING_RIGHT_UNARY_ARG;
             }
             if (!token_stack_.isEmpty()) {
                 if (token_stack_.last().isKNumber()) {
@@ -152,11 +152,11 @@ CalcEngine::ResultCode CalcEngine::calculate(const QQueue<KCalcToken> tokenBuffe
         case KCalcToken::TokenType::LEFT_UNARY_FUNCTION_TYPE:
             if (token_stack_.isEmpty()) {
                 errorIndex = token_index;
-                return MISIING_LEFT_UNARY_ARG;
+                return MISSING_LEFT_UNARY_ARG;
             }
             if (!token_stack_.last().isKNumber()) {
                 errorIndex = token_index;
-                return MISIING_LEFT_UNARY_ARG;
+                return MISSING_LEFT_UNARY_ARG;
             }
 
             if (token_stack_.size() > 1) {
@@ -187,7 +187,7 @@ CalcEngine::ResultCode CalcEngine::calculate(const QQueue<KCalcToken> tokenBuffe
         case KCalcToken::TokenType::BINARY_FUNCTION_TYPE:
             if (token_index + 1 >= buffer_size) {
                 errorIndex = token_index;
-                return MISIING_RIGHT_BINARY_ARG;
+                return MISSING_RIGHT_BINARY_ARG;
             }
 
             if (token_stack_.isEmpty()) {
@@ -290,7 +290,7 @@ CalcEngine::ResultCode CalcEngine::calculate(const QQueue<KCalcToken> tokenBuffe
         buffer_result_ = KNumber::Zero;
         errorIndex = buffer_size - 1;
         return EMPTY_INPUT;
-    } else if (token_stack_.last().isKNumber() && token_stack_.last().getKNumber().type() == KNumber::Type::TYPE_ERROR) {
+    } else if (token_stack_.last().isKNumber() && token_stack_.last().getKNumber().type() == KNumber::Type::TypeError) {
         error_ = true;
         errorIndex = buffer_size - 1;
         buffer_result_ = token_stack_.last().getKNumber();
@@ -305,12 +305,12 @@ CalcEngine::ResultCode CalcEngine::calculate(const QQueue<KCalcToken> tokenBuffe
     } else if (token_stack_.size() == 2 && token_stack_.last().isBinaryFunction() && token_stack_.at(0).isKNumber()) {
         error_ = true;
         errorIndex = buffer_size - 1;
-        if (token_stack_.at(0).getKNumber().type() == KNumber::Type::TYPE_ERROR) {
+        if (token_stack_.at(0).getKNumber().type() == KNumber::Type::TypeError) {
             token_stack_.clear();
             return MATH_ERROR;
         } else {
             token_stack_.clear();
-            return MISIING_RIGHT_BINARY_ARG;
+            return MISSING_RIGHT_BINARY_ARG;
         }
     } else if (!token_stack_.last().isKNumber()) {
         error_ = true;
